Normal mode analysis
====================

The different NMA models
------------------------

**Inheritance diagram**

.. inheritance-diagram:: tamkin.nma
   :parts: 1

.. automodule:: tamkin.nma
   :members:
   :show-inheritance:

Tools to analyze frequencies and modes
--------------------------------------

Some additional tools are in the ``nmatools.py`` code.

.. automodule:: tamkin.nmatools
   :members:
